@@ -19,7 +19,7 @@ from subprocess import check_call
 
 @task("release")
 @depends("publish")
-@description("Releasing your project using committer")
+@description('Release project using "setup.py sdist upload" and "setup.py bdist_wheel upload"')
 def release(project, logger):
     project_version = project.version
     logger.info("Releasing version {version}".format(version=project_version))
